==> haskell-deriving-aeson-0.2.10-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-deriving-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 deriving-aeson
version:              0.2.10
visibility:           public
id:                   deriving-aeson-0.2.10-LoTZCkgM6IYAXeC00OGSNS
key:                  deriving-aeson-0.2.10-LoTZCkgM6IYAXeC00OGSNS
license:              BSD-3-Clause
copyright:            Copyright (c) 2020 Fumiaki Kinoshita
maintainer:           fumiexcel@gmail.com
author:               Fumiaki Kinoshita
synopsis:             Type driven generic aeson instance customisation
description:
    This package provides a newtype wrapper with
    FromJSON/ToJSON instances customisable via a phantom type parameter.
    The instances can be rendered to the original type using DerivingVia.

category:             JSON, Generics
abi:                  f3956114fd30978b304f054bf340bf7e
exposed:              True
exposed-modules:      Deriving.Aeson Deriving.Aeson.Stock
import-dirs:          /usr/lib/ghc-9.4.8/site-local/deriving-aeson-0.2.10
library-dirs:         /usr/lib/ghc-9.4.8/site-local/deriving-aeson-0.2.10
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/deriving-aeson-0.2.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-deriving-aeson
hs-libraries:         HSderiving-aeson-0.2.10-LoTZCkgM6IYAXeC00OGSNS
depends:              aeson-2.1.2.1-7NKMY9av0haL3nHVKphSJj base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-deriving-aeson/html/deriving-aeson.haddock

haddock-html:         /usr/share/doc/haskell-deriving-aeson/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-deriving-aeson-0.2.10-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-deriving-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 deriving-aeson
version:              0.2.10
visibility:           public
id:                   deriving-aeson-0.2.10-BTV0zyX1IHV1VdEfQKIgXl
key:                  deriving-aeson-0.2.10-BTV0zyX1IHV1VdEfQKIgXl
license:              BSD-3-Clause
copyright:            Copyright (c) 2020 Fumiaki Kinoshita
maintainer:           fumiexcel@gmail.com
author:               Fumiaki Kinoshita
synopsis:             Type driven generic aeson instance customisation
description:
    This package provides a newtype wrapper with
    FromJSON/ToJSON instances customisable via a phantom type parameter.
    The instances can be rendered to the original type using DerivingVia.

category:             JSON, Generics
abi:                  823525af71a44cd3835bb5b340bdbf4e
exposed:              True
exposed-modules:      Deriving.Aeson Deriving.Aeson.Stock
import-dirs:          /usr/lib/ghc-9.4.8/site-local/deriving-aeson-0.2.10
library-dirs:         /usr/lib/ghc-9.4.8/site-local/deriving-aeson-0.2.10
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/deriving-aeson-0.2.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-deriving-aeson
hs-libraries:         HSderiving-aeson-0.2.10-BTV0zyX1IHV1VdEfQKIgXl
depends:              aeson-2.1.2.1-G4Y2VMvw6jlHlUlOzfqhge base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-deriving-aeson/html/deriving-aeson.haddock

haddock-html:         /usr/share/doc/haskell-deriving-aeson/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
